@@ -127,11 +127,14 @@ class YOLOv4(BaseClass):
         ]
 
         def representative_dataset_gen():
-            for _ in range(num_calibration_steps):
-                # pylint: disable=stop-iteration-return
-                # TODO: # of iteration
+            count = 0
+            while True:
                 images, _ = next(data_set)
-                yield [tf.cast(images[0:1, ...], tf.float32)]
+                for i in range(len(images)):
+                    yield [tf.cast(images[i : i + 1, ...], tf.float32)]
+                    count += 1
+                    if count >= num_calibration_steps:
+                        return
 
         if quantization:
             converter.optimizations = [tf.lite.Optimize.DEFAULT]
@@ -160,7 +163,12 @@ class YOLOv4(BaseClass):
     # Inference #
     #############
 
-    def predict(self, frame: np.ndarray):
+    def predict(
+        self,
+        frame: np.ndarray,
+        iou_threshold: float = 0.3,
+        score_threshold: float = 0.25,
+    ):
         """
         Predict one frame
 
@@ -187,7 +195,11 @@ class YOLOv4(BaseClass):
         candidates = np.concatenate(_candidates, axis=1)
 
         # Select 0
-        pred_bboxes = self.candidates_to_pred_bboxes(candidates[0])
+        pred_bboxes = self.candidates_to_pred_bboxes(
+            candidates[0],
+            iou_threshold=iou_threshold,
+            score_threshold=score_threshold,
+        )
         pred_bboxes = self.fit_pred_bboxes_to_original(pred_bboxes, frame.shape)
         return pred_bboxes
 
@@ -265,7 +277,9 @@ class YOLOv4(BaseClass):
             use_multiprocessing=False,
         )
 
-    def save_dataset_for_mAP(self, mAP_path, data_set, num_sample=1000):
+    def save_dataset_for_mAP(
+        self, mAP_path, data_set, num_sample=None, images_optional=False
+    ):
         """
         gt: name left top right bottom
         dr: name confidence left top right bottom
@@ -278,20 +292,25 @@ class YOLOv4(BaseClass):
 
         gt_dir_path = path.join(input_path, "ground-truth")
         dr_dir_path = path.join(input_path, "detection-results")
-        img_dir_path = path.join(input_path, "images-optional")
         makedirs(gt_dir_path)
         makedirs(dr_dir_path)
-        makedirs(img_dir_path)
+
+        if images_optional:
+            img_dir_path = path.join(input_path, "images-optional")
+            makedirs(img_dir_path)
 
         max_dataset_size = len(data_set)
 
+        if num_sample is None:
+            num_sample = max_dataset_size
+
         for i in range(num_sample):
             # image_path, [[x, y, w, h, class_id], ...]
             _dataset = data_set.dataset[i % max_dataset_size]
 
-            # images-optional
-            image_path = path.join(img_dir_path, "image_{}.jpg".format(i))
-            shutil.copy(_dataset[0], image_path)
+            if images_optional:
+                image_path = path.join(img_dir_path, "image_{}.jpg".format(i))
+                shutil.copy(_dataset[0], image_path)
 
             image = cv2.imread(_dataset[0])
             image = cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
@@ -303,7 +322,8 @@ class YOLOv4(BaseClass):
 
             # ground-truth
             with open(
-                path.join(gt_dir_path, "image_{}.txt".format(i)), "w",
+                path.join(gt_dir_path, "image_{}.txt".format(i)),
+                "w",
             ) as fd:
                 for xywhc in _dataset[1]:
                     # name left top right bottom
@@ -325,7 +345,8 @@ class YOLOv4(BaseClass):
 
             # detection-results
             with open(
-                path.join(dr_dir_path, "image_{}.txt".format(i)), "w",
+                path.join(dr_dir_path, "image_{}.txt".format(i)),
+                "w",
             ) as fd:
                 for xywhcp in pred_bboxes:
                     # name confidence left top right bottom
