@@ -93,7 +93,7 @@ class Dataset:
             txt = fd.readlines()
             if self.dataset_type == "converted_coco":
                 for line in txt:
-                    # line: "<image_path> class_id, x, y, w, h ..."
+                    # line: "<image_path> class_id,x,y,w,h ..."
                     bboxes = line.strip().split()
                     image_path = bboxes[0]
                     if self.image_path_prefix:
@@ -141,13 +141,20 @@ class Dataset:
         """
         @param bboxes: [[b_x, b_y, b_w, b_h, class_id], ...]
 
-        @return [s, m, l]
+        @return [s, m, l] or [s, l]
             Dim(1, grid_y, grid_x, anchors,
                                 (b_x, b_y, b_w, b_h, conf, prob_0, prob_1, ...))
         """
         ground_truth = [
             np.zeros(
-                (1, _size, _size, 3, 5 + self.num_classes,), dtype=np.float32,
+                (
+                    1,
+                    _size,
+                    _size,
+                    3,
+                    5 + self.num_classes,
+                ),
+                dtype=np.float32,
             )
             for _size in self.grid_size
         ]
@@ -268,7 +275,7 @@ class Dataset:
     def __next__(self):
         """
         @return image, ground_truth
-            ground_truth == (s_truth, m_truth, l_truth) or (m_truth, l_truth)
+            ground_truth == (s_truth, m_truth, l_truth) or (s_truth, l_truth)
         """
         if self.batch_size > 1:
             batch_x = []
@@ -376,16 +383,28 @@ def mosaic(dataset0, dataset1, dataset2, dataset3):
     ]
 
     image[:, :partition_y, :partition_x, :] = dataset0[0][
-        :, top[0] : down[0], left[0] : right[0], :,
+        :,
+        top[0] : down[0],
+        left[0] : right[0],
+        :,
     ]
     image[:, :partition_y, partition_x:, :] = dataset1[0][
-        :, top[1] : down[1], left[1] : right[1], :,
+        :,
+        top[1] : down[1],
+        left[1] : right[1],
+        :,
     ]
     image[:, partition_y:, :partition_x, :] = dataset2[0][
-        :, top[2] : down[2], left[2] : right[2], :,
+        :,
+        top[2] : down[2],
+        left[2] : right[2],
+        :,
     ]
     image[:, partition_y:, partition_x:, :] = dataset3[0][
-        :, top[3] : down[3], left[3] : right[3], :,
+        :,
+        top[3] : down[3],
+        left[3] : right[3],
+        :,
     ]
 
     for i, _bboxes in enumerate(
